==> networkmanager-qt-5.15.0.zip: networkmanager-qt-5.15.0/src/olpcmeshdevice_p.h <==
/*
    Copyright 2011 Ilia Kats <ilia-kats@gmx.net>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef NETWORKMANAGERQT_OLPCMESHDEVICE_P_H
#define NETWORKMANAGERQT_OLPCMESHDEVICE_P_H

#include "device_p.h"
#include "dbus/nm-device-olpc-meshinterface.h"

namespace NetworkManager
{

class OlpcMeshDevicePrivate : public DevicePrivate
{
    Q_OBJECT
public:
    explicit OlpcMeshDevicePrivate(const QString &path, OlpcMeshDevice *q);
    OrgFreedesktopNetworkManagerDeviceOlpcMeshInterface iface;
    uint activeChannel;
    QString companion;
    QString hardwareAddress;

    Q_DECLARE_PUBLIC(OlpcMeshDevice)
protected:
    /**
     * When subclassing make sure to call the parent class method
     * if the property was not useful to your new class
     */
    virtual void propertyChanged(const QString &property, const QVariant &value) Q_DECL_OVERRIDE;
};

}

#endif

==> networkmanager-qt-5.35.0.zip: networkmanager-qt-5.35.0/src/olpcmeshdevice_p.h <==
/*
    Copyright 2011 Ilia Kats <ilia-kats@gmx.net>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef NETWORKMANAGERQT_OLPCMESHDEVICE_P_H
#define NETWORKMANAGERQT_OLPCMESHDEVICE_P_H

#include "device_p.h"
#include "dbus/olpcmeshdeviceinterface.h"

namespace NetworkManager
{

class OlpcMeshDevicePrivate : public DevicePrivate
{
    Q_OBJECT
public:
    explicit OlpcMeshDevicePrivate(const QString &path, OlpcMeshDevice *q);
    OrgFreedesktopNetworkManagerDeviceOlpcMeshInterface iface;
    uint activeChannel;
    QString companion;
    QString hardwareAddress;

    Q_DECLARE_PUBLIC(OlpcMeshDevice)
protected:
    /**
     * When subclassing make sure to call the parent class method
     * if the property was not useful to your new class
     */
    virtual void propertyChanged(const QString &property, const QVariant &value) Q_DECL_OVERRIDE;
};

}

#endif
